@@ -110,8 +110,7 @@ void GlobalData::read()
   optSize = config->readSizeEntry("Opt_Size",&invalid);
   setsSize = config->readSizeEntry("Sets_Size",&invalid);
   matchSize = config->readSizeEntry("Match_Size",&invalid);
-  showMatchList = config->readBoolEntry("Show_MatchList",true);
-  swallowMatchList = config->readBoolEntry("Swallow_MatchList",true);
+  showMatchList = config->readBoolEntry("Show_MatchList",false);
   splitterSizes = config->readIntListEntry("Splitter_Sizes");
 
   config->setGroup("Query Combo");
@@ -148,7 +147,7 @@ void GlobalData::read()
     strategies.append(i18n("Prefix"));
   } else {
     strategies.remove(strategies.begin());
-    strategies.prepend(i18n("spell check"));
+    strategies.prepend(i18n("Spell Check"));
   }
 
   currentStrategy = config->readNumEntry("Current_Strategy",0);
@@ -175,7 +174,7 @@ void GlobalData::read()
   databases = serverDatabases;
   for (int i = databaseSets.count()-1;i>=0;i--)
     databases.prepend(databaseSets.at(i)->first());
-  databases.prepend(i18n("all databases"));
+  databases.prepend(i18n("All Databases"));
   if (currentDatabase >= databases.count())
     currentDatabase = 0;
 }
@@ -212,7 +211,6 @@ void GlobalData::write()
   config->writeEntry("Sets_Size",setsSize);
   config->writeEntry("Match_Size",matchSize);
   config->writeEntry("Show_MatchList",showMatchList);
-  config->writeEntry("Swallow_MatchList",swallowMatchList);
   config->writeEntry("Splitter_Sizes",splitterSizes);
 
   config->setGroup("Query Combo");
