@@ -88,22 +88,22 @@ DbSetsDialog::DbSetsDialog(QWidget *parent, const char *name)
   subLayout2->addMultiCellWidget(w_leftBox,1,6,0,0);
 
   w_allLeft = new QPushButton(page);
-  w_allLeft->setPixmap(BarIcon("2leftarrow"));
+  w_allLeft->setIconSet(BarIconSet("2leftarrow"));
   connect(w_allLeft, SIGNAL(clicked()),this, SLOT(allLeftPressed()));
   subLayout2->addWidget(w_allLeft,2,1);
 
   w_left = new QPushButton(page);
-  w_left->setPixmap(BarIcon("1leftarrow"));
+  w_left->setIconSet(BarIconSet("1leftarrow"));
   connect(w_left, SIGNAL(clicked()),this, SLOT(leftPressed()));
   subLayout2->addWidget(w_left,3,1);
 
   w_right = new QPushButton(page);
-  w_right->setPixmap(BarIcon("1rightarrow"));
+  w_right->setIconSet(BarIconSet("1rightarrow"));
   connect(w_right, SIGNAL(clicked()),this, SLOT(rightPressed()));
   subLayout2->addWidget(w_right,4,1);
 
   w_allRight = new QPushButton(page);
-  w_allRight->setPixmap(BarIcon("2rightarrow"));
+  w_allRight->setIconSet(BarIconSet("2rightarrow"));
   connect(w_allRight, SIGNAL(clicked()),this, SLOT(allRightPressed()));
   subLayout2->addWidget(w_allRight,5,1);
 
