@@ -2,7 +2,7 @@
 *                               dlgIndividual.h
 *                             -------------------
 *
-*    Revision     : $Id: dlgIndividual.h 476275 2005-11-01 01:30:58Z thiago $
+*    Revision     : $Id: dlgIndividual.h 530904 2006-04-18 00:26:19Z rohanpm $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -31,6 +31,8 @@
 
 #include <qwidget.h>
 
+#include <kio/global.h>
+
 class Transfer;
 
 class QLabel;
@@ -57,9 +59,9 @@ public:
     void enableOpenFile();
 
 public slots:
-    void setTotalSize(unsigned long bytes);
+    void setTotalSize(KIO::filesize_t bytes);
 
-    void setProcessedSize(unsigned long bytes);
+    void setProcessedSize(KIO::filesize_t bytes);
 
     void setSpeed(QString speed);
     void setPercent(unsigned long percent);
@@ -103,7 +105,7 @@ protected:
 
     bool bKeepDlgOpen;
 
-    unsigned long m_iTotalSize;
+    KIO::filesize_t m_iTotalSize;
     
     bool advanced;
 }
