@@ -2,7 +2,7 @@
 *                                slave.cpp
 *                             -------------------
 *
-*    Revision     : $Id: slave.cpp 393074 2005-02-25 19:25:18Z ratz $
+*    Revision     : $Id: slave.cpp 530904 2006-04-18 00:26:19Z rohanpm $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -70,7 +70,7 @@ void Slave::Op(SlaveCommand _cmd)
 }
 
 /** No descriptions */
-void Slave::PostMessage(SlaveResult _event, unsigned long _data)
+void Slave::PostMessage(SlaveResult _event, Q_ULLONG _data)
 {
     SlaveEvent *e1 = new SlaveEvent(m_parent, _event, _data);
 
@@ -297,7 +297,7 @@ void Slave::slotSpeed(KIO::Job *, unsigned long lSpeed)
 
 void Slave::slotTotalSize(KIO::Job *, KIO::filesize_t _total_size)
 {
-    mDebugIn << "= " << (unsigned long) _total_size << endl;
+    mDebugIn << "= " << _total_size << endl;
 
     if ((int)_total_size == 0)//shouldn't happen, but does
         return;
