@@ -234,7 +234,7 @@ void ProgramNewsSource::slotProgramExited(KProcess *proc)
 			errorMsg += i18n("<p>Program output:<br>%1<br>").arg(output);
 		}
 		KMessageBox::detailedError(0, i18n("An error occurred while updating the"
-					" news source '%1'!").arg(newsSourceName()), errorMsg,
+					" news source '%1'.").arg(newsSourceName()), errorMsg,
 				i18n("KNewsTicker Error"));
 	}
 
@@ -312,8 +312,8 @@ QString ProgramNewsSource::errorMessage(const ErrorCode errorCode)
 		case ENOTFOUND: return i18n("The program '%1' tried to access data which"
 				" could not be found.");
 		case ETIMEOUT: return i18n("The HTTP request of the program '%1' timed out.");
-		case ESERVERE: return i18n("A server error has been encountered. It's likely"
-				" that you can't do anything about it.");
+		case ESERVERE: return i18n("A server error has been encountered. It is likely"
+				" that you cannot do anything about it.");
 		case EHTTPNOSUP: return i18n("The HTTP protocol version used by the program"
 				" '%1' was not understood by the HTTP server or source.");
 		default: return i18n("KNewsTicker was unable to detect the exact reasons for"
