@@ -316,13 +316,11 @@ void KNewsTickerConfig::addFilter(const ArticleFilter &fd)
 
 void KNewsTickerConfig::removeNewsSource()
 {
-	if (KMessageBox::warningYesNo(this, i18n("<p>Do you really want to remove %n news"
-							" source?</p><p>Press 'Yes' to remove the news source from the list,"
-							" press 'No' to keep it and close this dialog.</p>",
+	if (KMessageBox::warningContinueCancel(this, i18n("<p>Do you really want to remove %n news"
+							" source?</p>",
 						 "<p>Do you really want to remove these %n news"
-							" sources?</p><p>Press 'Yes' to remove the news sources from the list,"
-							" press 'No' to keep them and close this dialog.</p>",
-						 m_child->lvNewsSources->selectedItems().count())) == KMessageBox::Yes) {
+							" sources?</p>",
+						 m_child->lvNewsSources->selectedItems().count()), QString::null, KStdGuiItem::del()) == KMessageBox::Continue) {
 		int itemCount = m_child->lvNewsSources->selectedItems().count();
 		for (int j = 0; j < itemCount; j++) {
 			if (m_child->lvNewsSources->selectedItems().isEmpty()) { break; }
@@ -344,9 +342,8 @@ void KNewsTickerConfig::removeNewsSource()
 
 void KNewsTickerConfig::removeFilter(QListViewItem *item)
 {
-	if (KMessageBox::warningYesNo(this, i18n("<p>Do you really want to remove the selected"
-					" filter?</p><p>Press 'Yes' to remove the filter from the list, press"
-					" 'No' to keep it and close this dialog.</p>")) == KMessageBox::Yes) {
+	if (KMessageBox::warningContinueCancel(this, i18n("<p>Do you really want to remove the selected"
+					" filter?</p>"), QString::null, KStdGuiItem::del()) == KMessageBox::Continue) {
 		delete item;
 		m_child->bRemoveFilter->setEnabled(false);
 	}
