@@ -35,6 +35,7 @@ class NewsScroller : public QFrame
 	public:
 		NewsScroller(QWidget *, ConfigAccess *, const char * = 0);
 
+		virtual QSize sizeHint() const;
 		virtual QSizePolicy sizePolicy() const;
 	
 		// Convenience stuff. Somehow ugly, no?	
@@ -81,6 +82,7 @@ class NewsScroller : public QFrame
 		int scrollHeight() const;
 		bool updateActive(const QPoint &);
 		bool isHeadline(const QString &) const;
+		int speedAsInterval( int speed );
 
 	private:
 		friend class Headline;
@@ -93,6 +95,8 @@ class NewsScroller : public QFrame
 		QPoint       m_dragPos;
 		bool         m_mouseDrag;
 		QString      m_tempHeadline;
+		float        m_totalStepping;
+		float        m_stepping;
 };
 
 #endif // NEWSSCROLLER_H
