@@ -1,7 +1,7 @@
 /*
     accountconfig.h  -  Kopete account config page
 
-    Copyright (c) 2003 by Olivier Goffart <ogoffart@tiscalinet.be>
+    Copyright (c) 2003-2004 by Olivier Goffart <ogoffart @ kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -16,14 +16,20 @@
 #ifndef __ACCOUNTCONFIG_H
 #define __ACCOUNTCONFIG_H
 
-#include "kcmodule.h"
-#include <kopeteaccount.h>
+#include <kcmodule.h>
+#include <qmap.h>
+#include <qcolor.h>
+
+namespace Kopete
+{
+class Account;
+}
 
-/**
- * @author Olivier Goffart <ogoffart@tiscalinet.be>
- */
 class KopeteAccountConfigBase;
 
+/**
+ * @author Olivier Goffart <ogoffart @ kde.org>
+ */
 class KopeteAccountConfig : public KCModule
 {
 	Q_OBJECT
@@ -37,7 +43,8 @@ public slots:
 
 private:
 	KopeteAccountConfigBase *m_view;
-	KopeteAccount *previousAccount;
+	QMap<Kopete::Account* , QColor> m_newColors;
+	bool m_protected;
 
 private slots:
 	void slotRemoveAccount();
@@ -47,6 +54,7 @@ private slots:
 	void slotItemSelected();
 	void slotAccountUp();
 	void slotAccountDown();
+	void slotColorChanged();
 };
 #endif
 
