@@ -256,8 +256,6 @@ AppearanceConfig::AppearanceConfig(QWidget *parent, const char* /*name*/, const
 		this, SLOT(slotEditTooltips()));
 	connect(d->mPrfsContactList->mIndentContacts, SIGNAL(toggled(bool)),
 		this, SLOT(emitChanged()));
-	connect(d->mPrfsContactList->mHideVerticalScrollBar, SIGNAL(toggled(bool)),
-		this, SLOT(emitChanged()) );
 	connect(d->mPrfsContactList->mDisplayMode, SIGNAL(clicked(int)),
 		this, SLOT(emitChanged()));
 	connect(d->mPrfsContactList->mIconMode, SIGNAL(toggled(bool)),
@@ -270,8 +268,6 @@ AppearanceConfig::AppearanceConfig(QWidget *parent, const char* /*name*/, const
 		this, SLOT(emitChanged()));
 	connect(d->mPrfsContactList->mAutoHide, SIGNAL(toggled(bool)),
 		this, SLOT(emitChanged()));
-	connect(d->mPrfsContactList->mAutoHideVScroll, SIGNAL(toggled(bool)),
-		this, SLOT(emitChanged()));
 	connect(d->mPrfsContactList->mAutoHideTimeout, SIGNAL(valueChanged(int)),
 		this, SLOT(emitChanged()));
 
@@ -368,7 +364,6 @@ void AppearanceConfig::save()
 	p->setTreeView(d->mPrfsContactList->mTreeContactList->isChecked());
 	p->setSortByGroup(d->mPrfsContactList->mSortByGroup->isChecked());
 	p->setContactListIndentContacts(d->mPrfsContactList->mIndentContacts->isChecked());
-	p->setContactListHideVerticalScrollBar(d->mPrfsContactList->mHideVerticalScrollBar->isChecked());
 	p->setContactListDisplayMode(KopetePrefs::ContactDisplayMode(d->mPrfsContactList->mDisplayMode->selectedId()));
 	p->setContactListIconMode(KopetePrefs::IconDisplayMode((d->mPrfsContactList->mIconMode->isChecked()) ? KopetePrefs::PhotoPic : KopetePrefs::IconPic));
 	p->setContactListAnimation(d->mPrfsContactList->mAnimateChanges->isChecked());
@@ -389,7 +384,6 @@ void AppearanceConfig::save()
 	p->setContactListCustomNormalFont(d->mPrfsColors->mNormalFont->font());
 	p->setContactListGroupNameColor(d->mPrfsColors->mGroupNameColor->color());
 	p->setContactListAutoHide(d->mPrfsContactList->mAutoHide->isChecked());
-	p->setContactListAutoHideVScroll(d->mPrfsContactList->mAutoHideVScroll->isChecked());
 	p->setContactListAutoHideTimeout(d->mPrfsContactList->mAutoHideTimeout->value());
 
 	p->setBgOverride( d->mPrfsColors->mBgOverride->isChecked() );
@@ -423,7 +417,6 @@ void AppearanceConfig::load()
 	d->mPrfsContactList->mTreeContactList->setChecked( p->treeView() );
 	d->mPrfsContactList->mSortByGroup->setChecked( p->sortByGroup() );
 	d->mPrfsContactList->mIndentContacts->setChecked( p->contactListIndentContacts() );
-	d->mPrfsContactList->mHideVerticalScrollBar->setChecked( p->contactListHideVerticalScrollBar() );
 
         // convert old single value display mode to dual display/icon modes
         if (p->contactListDisplayMode() == KopetePrefs::Yagami) {
@@ -443,7 +436,6 @@ void AppearanceConfig::load()
 #endif
 	d->mPrfsContactList->mFoldVisibility->setChecked( p->contactListFolding() );
 	d->mPrfsContactList->mAutoHide->setChecked( p->contactListAutoHide() );
-	d->mPrfsContactList->mAutoHideVScroll->setChecked( p->contactListAutoHideVScroll() );
 	d->mPrfsContactList->mAutoHideTimeout->setValue( p->contactListAutoHideTimeout() );
 
 	// "Colors & Fonts" TAB =====================================================
@@ -540,7 +532,7 @@ void AppearanceConfig::slotSelectedEmoticonsThemeChanged()
 	d->mPrfsEmoticons->btnRemoveTheme->setEnabled( fileInf.isWritable() );
 
 	Kopete::Emoticons emoticons( themeName );
-	QStringList smileys = emoticons.emoticonAndPicList().values();
+	QStringList smileys = emoticons.emoticonAndPicList().keys();
 	QString newContentText = "<qt>";
 
 	for(QStringList::Iterator it = smileys.begin(); it != smileys.end(); ++it )
@@ -771,6 +763,7 @@ void AppearanceConfig::createPreviewMessages()
 	msgHigh.setImportance( Kopete::Message::Highlight );
 	// This is a UTF-8 string btw.
 	Kopete::Message msgRightToLeft(d->myself, d->jack, i18n("This special UTF-8 string is to test if the style support Right-to-Left language display.", "הודעות טקסט"), Kopete::Message::Outbound);
+	Kopete::Message msgExplanation( d->myself, d->jack, i18n( "That message was in a Right-to-Left language, which Kopete also supports." ), Kopete::Message::Outbound );
 	Kopete::Message msgBye ( d->myself, d->jack,   i18n( "Bye" ), Kopete::Message::Outbound );
 
 	// Add the messages to ChatMessagePart
@@ -783,6 +776,7 @@ void AppearanceConfig::createPreviewMessages()
 	d->preview->appendMessage(msgAct);
 	d->preview->appendMessage(msgHigh);
 	d->preview->appendMessage(msgRightToLeft);
+	d->preview->appendMessage(msgExplanation);
 	d->preview->appendMessage(msgBye);
 }
 
