@@ -1,7 +1,7 @@
 /*
     videodevicepool.h  -  Kopete Multiple Video Device handler Class
 
-    Copyright (c) 2005 by Cláudio da Silveira Pinheiro   <taupter@gmail.com>
+    Copyright (c) 2005-2006 by Cláudio da Silveira Pinheiro   <taupter@gmail.com>
 
     Kopete    (c) 2002-2003      by the Kopete developers  <kopete-devel@kde.org>
 
@@ -27,6 +27,7 @@
 #include <qstring.h>
 #include <qimage.h>
 #include <qvaluevector.h>
+#include <qmutex.h>
 #include <kcombobox.h>
 #include "videodevice.h"
 #include "kopete_export.h"
@@ -78,6 +79,7 @@ public:
 	VideoDeviceModelPool m_modelvector;  // Vector to be filled with unique device models
 	int fillDeviceKComboBox(KComboBox *combobox);
 	int fillInputKComboBox(KComboBox *combobox);
+	int fillStandardKComboBox(KComboBox *combobox);
 	unsigned int currentDevice();
 	int currentInput();
 	unsigned int inputs();
@@ -92,14 +94,13 @@ public:
 	float setWhiteness(float whiteness);
 	float getHue();
 	float setHue(float hue);
+
 	bool getAutoBrightnessContrast();
 	bool setAutoBrightnessContrast(bool brightnesscontrast);
 	bool getAutoColorCorrection();
 	bool setAutoColorCorrection(bool colorcorrection);
 	bool getImageAsMirror();
 	bool setImageAsMirror(bool imageasmirror);
-	bool getWorkaroundBrokenDriver();
-	bool setWorkaroundBrokenDriver(bool workaroundbrokendriver);
 
 	void loadConfig(); // Load configuration parameters;
 	void saveConfig(); // Save configuretion parameters;
@@ -111,9 +112,12 @@ protected:
 	void guessDriver();
 	unsigned int m_current_device;
 	struct imagebuffer m_buffer; // only used when no devices were found
+
+	QMutex m_ready;
 private:
 	VideoDevicePool();
 	static VideoDevicePool* s_self;
+	static __u64 m_clients; // Number of instances
 };
 
 }
