@@ -2,7 +2,7 @@
     editaccountwidget.h - Kopete Account Widget
 
     Copyright (c) 2002-2003 by Martijn Klingens      <klingens@kde.org>
-    Copyright (c) 2003      by Olivier Goffart       <ogoffart@tiscalinet.be>
+    Copyright (c) 2003      by Olivier Goffart       <ogoffart @ kde.org>
 
     Kopete    (c) 2002-2003 by the Kopete developers <kopete-devel@kde.org>
 
@@ -19,7 +19,7 @@
 #ifndef EDITACCOUNTWIDGET_H
 #define EDITACCOUNTWIDGET_H
 
-#include <kopete_export.h>
+#include "kopete_export.h"
 
 namespace Kopete
 {
@@ -29,7 +29,7 @@ class Account;
 class KopeteEditAccountWidgetPrivate;
 
 /**
- * @author Olivier Goffart <ogoffart@tiscalinet.be>
+ * @author Olivier Goffart <ogoffart @ kde.org>
  *
  * This class is used by the protocol plugins to add specific protocol fields in the add account wizard,
  * or in the account preferences. If the given account is 0L, then you will have to create a new account
@@ -44,15 +44,7 @@ class KopeteEditAccountWidgetPrivate;
  *   field has to be marked as ReadOnly or shown as a label if the account already exists. Remember
  *   that accountId should be constant after account creation!
  *
- * - The password, and the remember password checkboxes. When creating the widget you have to get if
- *   the password is remembered, with @ref Kopete::Account::rememberPassword(). If it returns true
- *   you can use @ref Kopete::Account::password() to get the password field.
- *
- *   WARNING: Do not use password() if the password is not remembered, or Kopete will popup a dialog
- *            to ask the password!
- *
- *   To set the password use @ref Kopete::Account::setPassword(). If the user has not selected the
- *   'remember password' checkbox, set the password to QString::null.
+ * - The password, and the remember password checkboxes.
  *
  * - The auto connect checkbox: use @ref Kopete::Account::excludeConnect() and
  *   @ref Kopete::Account::setExcludeConnect() to get/set this flag.
