@@ -88,12 +88,14 @@ class HistoryDialog : public KDialogBase
 		void slotSearchErase();
 		void slotSearchTextChanged(const QString& txt); // To enable/disable search button
 		void slotContactChanged(int index);
-
-		void searchFirstStep();
+		void slotFilterChanged(int index);
 
 		void init();
 		void slotLoadDays();
 
+		void slotRightClick(const QString &url, const QPoint &point);
+		void slotCopy();
+		void slotCopyURL();
 
 	private:
 		enum Disabled { Prev=1, Next=2 };
@@ -116,8 +118,6 @@ class HistoryDialog : public KDialogBase
 		 */
 		bool hasChild(KListViewItem* item, int month);
 
-		HistoryLogger *mLogger;
-
 		/**
 		 * We show history dialog to look at the log for a metacontact. Here is this metacontact.
 		 */
@@ -136,20 +136,11 @@ class HistoryDialog : public KDialogBase
 			QValueList<DMPair> dateMCList; // mc for MetaContact
 		} mInit;
 
-		struct Search
-		{
-				typedef QMap<QDate, QValueList<Kopete::MetaContact*> > DateSearchMap;
-				DateSearchMap dateSearchMap;
+		bool mSearching;
 
-				KListViewDateItem *item;
-
-				int resultMatches;
-
-				bool foundPrevious;
-				QDate datePrevious;
-
-				Kopete::MetaContact *currentMetaContact;
-		} *mSearch;
+		KAction *mCopyAct;
+		KAction *mCopyURLAct;
+		QString mURL;
 };
 
 #endif
