@@ -3,13 +3,10 @@
 
     Kopete Now Listening To plugin
 
+    Copyright (c) 2005           by Tommi Rantala <tommi.rantala@cs.helsinki.fi>
     Copyright (c) 2002,2003,2004 by Will Stephenson <will@stevello.free-online.co.uk>
 
-    Kopete    (c) 2002,2003,2004 by the Kopete developers  <kopete-devel@kde.org>
-
-	Purpose:
-	This class abstracts the interface to Noatun by
-	implementing NLMediaPlayer
+    Kopete    (c) 2002-2005      by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -27,20 +24,30 @@
 #include <qobject.h>
 #include <kxmlguiclient.h>
 
-#include "kopetemessage.h"
-#include "kopeteplugin.h"
+class KAction;
+class NowListeningPlugin;
 
-class NowListeningGUIClient : public QObject , public KXMLGUIClient
+namespace Kopete {
+	class ChatSession;
+}
+
+class NowListeningGUIClient : public QObject, public KXMLGUIClient
 {
-Q_OBJECT
-	public:
-		NowListeningGUIClient( Kopete::ChatSession *parent );
-		virtual ~NowListeningGUIClient() {}
-	protected slots:
-		void slotAdvertToCurrentChat();
+	Q_OBJECT
 
-	private:
-		Kopete::ChatSession* m_msgManager;
+public:
+	NowListeningGUIClient( Kopete::ChatSession* parent, NowListeningPlugin* plugin );
+	virtual ~NowListeningGUIClient() {}
+
+protected slots:
+	void slotAdvertToCurrentChat();
+	void slotPluginUnloaded();
+
+private:
+	Kopete::ChatSession* m_msgManager;
+	KAction* m_action;
 };
 
 #endif
+
+// vim: set noet ts=4 sts=4 sw=4:
