@@ -53,7 +53,7 @@ GroupWiseAddContactPage::GroupWiseAddContactPage( Kopete::Account * owner, QWidg
 	( new QVBoxLayout( this ) )->setAutoAdd( true );
 	if (owner->isConnected ())
 	{
-		m_searchUI = new GroupWiseSearch( m_account, QListView::Single, false,
+		m_searchUI = new GroupWiseContactSearch( m_account, QListView::Single, false,
 				 this, "acwsearchwidget" );
 		show();
 		m_canadd = true;
