@@ -18,21 +18,32 @@
 #ifndef IRCCONTACTMANAGER_H
 #define IRCCONTACTMANAGER_H
 
-#include <qmap.h>
+#include <qdict.h>
 #include <qobject.h>
 #include <qstring.h>
+#include <qstringlist.h>
 
-class QTimer;
+class IRCContact;
+class IRCAccount;
 
-class KopeteMetaContact;
-class KopeteView;
-
-class KIRC;
 class IRCServerContact;
 class IRCChannelContact;
 class IRCUserContact;
-class IRCContact;
-class IRCAccount;
+
+namespace KIRC
+{
+class Engine;
+}
+
+namespace Kopete
+{
+class Contact;
+class MetaContact;
+}
+
+class KopeteView;
+
+class QTimer;
 
 /**
  * @author Michel Hermier <michel.hermier@wanadoo.fr>
@@ -53,21 +64,23 @@ class IRCContactManager
 		IRCServerContact *myServer() const { return m_myServer; }
 		IRCUserContact *mySelf() const { return m_mySelf; }
 
-		IRCChannelContact *findChannel(const QString &channel, KopeteMetaContact *m=0);
+		IRCChannelContact *findChannel(const QString &channel, Kopete::MetaContact *m=0);
 		IRCChannelContact *existChannel(const QString &channel) const;
 
-		IRCUserContact *findUser(const QString &nick, KopeteMetaContact *m=0);
+		IRCUserContact *findUser(const QString &nick, Kopete::MetaContact *m=0);
 		IRCUserContact *existUser(const QString &nick) const;
 
-		IRCContact *findContact(const QString &nick, KopeteMetaContact *m=0);
+		IRCContact *findContact(const QString &nick, Kopete::MetaContact *m=0);
 		IRCContact *existContact( const QString &id ) const;
 
-		static IRCContact *existContact(const KIRC *engine, const QString &nick);
+		QValueList<IRCChannelContact*> findChannelsByMember( IRCUserContact *contact );
+
+		static IRCContact *existContact(const KIRC::Engine *engine, const QString &nick);
 
 	public slots:
-		void unregister(KopeteContact *contact);
-		void unregisterUser(KopeteContact *contact, bool force = false );
-		void unregisterChannel(KopeteContact *contact, bool force = false );
+		void unregister(Kopete::Contact *contact);
+		void unregisterUser(Kopete::Contact *contact, bool force = false );
+		void unregisterChannel(Kopete::Contact *contact, bool force = false );
 
 		void addToNotifyList(const QString &nick);
 		void removeFromNotifyList(const QString &nick);
@@ -82,6 +95,7 @@ class IRCContactManager
 		void slotIsonRecieved();
 		void slotIsonTimeout();
 		void slotNewNickChange(const QString &oldnick, const QString &newnick);
+		void slotContactAdded( Kopete::MetaContact *contact );
 
 	private:
 		QDict<IRCChannelContact> m_channels;
@@ -99,5 +113,5 @@ class IRCContactManager
 		static const QRegExp isChannel;
 };
 
-#endif // IRCCONTACTMANAGER_H
+#endif
 
