@@ -20,6 +20,7 @@
 #ifndef KIRCENGINE_H
 #define KIRCENGINE_H
 
+#include "kircentity.h"
 #include "kircmessage.h"
 #include "kircmessageredirector.h"
 #include "kirctransfer.h"
@@ -94,6 +95,16 @@ public:
 		Disconnected
 	};
 
+	enum ServerMessageType
+	{
+		ErrorMessage = -1,
+		PrivateMessage,
+		InfoMessage,
+
+		MessageOfTheDayMessage,
+		MessageOfTheDayCondensedMessage
+	};
+
 	Engine( QObject *parent = 0, const char* name = 0 );
 	~Engine();
 
@@ -172,6 +183,8 @@ public:
 	inline void addCustomCtcp( const QString &ctcp, const QString &reply )
 	{ customCtcpMap[ ctcp.lower() ] = reply; }
 
+	KIRC::EntityPtr getEntity(const QString &name);
+
 public slots:
 	//Message output
 	void writeRawMessage(const QString &message);
@@ -247,7 +260,7 @@ public slots:
 	void topic(const QString &channel, const QString &topic);
 	void user(const QString &newUsername, const QString &hostname, const QString &newRealname);
 	void user(const QString &newUsername, Q_UINT8 mode, const QString &newRealname);
-	void whoisUser(const QString &user);
+	void whois(const QString &user);
 
 
 	/* CTCP commands */
@@ -266,17 +279,26 @@ signals:
 
 	void receivedMessage(KIRC::Message &);
 
-	void successfullyChangedNick(const QString &, const QString &);
-
-	/** Give a server message as a string.
-	 * The given server message could have been translated to your locale.
+	/**
+	 * Emit a received message.
+	 * The received message could have been translated to your locale.
+	 *
+	 * @param type the message type.
+	 * @param from the originator of the message.
+	 * @param to is the list of entities that are related to this message.
+	 * @param msg the message (usually translated).
 	 *
-	 * @note This method obsolete incomingConnectString.
 	 * @note Most of the following numeric messages should be deprecated, and call this method instead.
 	 *	 Most of the methods, using it, update KIRC::Entities.
-	 *	 Some of the known untranslable message (like MOTD) are sent indirectly, via dedicated API.
+	 *	 Lists based messages are sent via dedicated API, therefore they don't use this.
 	 */
-//	void serverMessage(const QString &msg);
+	// @param args the args to apply to this message.
+	void receivedMessage(	KIRC::Engine::ServerMessageType type,
+				const KIRC::EntityPtr &from,
+				const KIRC::EntityPtrList &to,
+				const QString &msg);
+
+	void successfullyChangedNick(const QString &, const QString &);
 
 	//ServerContact Signals
 	void incomingMotd(const QString &motd);
@@ -358,15 +380,16 @@ signals:
 	void incomingCtcpReply(const QString &type, const QString &target, const QString &messageReceived);
 
 private slots:
+	void destroyed(KIRC::Entity *entity);
+
 	void slotReadyRead();
 
 	void slotConnected();
 	void slotConnectionClosed();
 	void error(int errCode = 0);
 
-	inline void ignoreMessage(KIRC::Message &){}
-
-	void dumpSuffix(KIRC::Message &);
+	void ignoreMessage(KIRC::Message &msg);
+	void emitSuffix(KIRC::Message &);
 
 	void error(KIRC::Message &msg);
 	void join(KIRC::Message &msg);
@@ -400,9 +423,10 @@ private slots:
 	void numericReply_303(KIRC::Message &msg);
 //	void numericReply_305(KIRC::Message &msg);
 //	void numericReply_306(KIRC::Message &msg);
-//	void numericReply_307(KIRC::Message &msg);
+	void numericReply_307(KIRC::Message &msg);
 	void numericReply_311(KIRC::Message &msg);
 	void numericReply_312(KIRC::Message &msg);
+	void numericReply_313(KIRC::Message &msg);
 	void numericReply_314(KIRC::Message &msg);
 	void numericReply_315(KIRC::Message &msg);
 	void numericReply_317(KIRC::Message &msg);
@@ -420,11 +444,13 @@ private slots:
 	void numericReply_352(KIRC::Message &msg);
 	void numericReply_353(KIRC::Message &msg);
 	void numericReply_366(KIRC::Message &msg);
+	void numericReply_369(KIRC::Message &msg);
 	void numericReply_372(KIRC::Message &msg);
 //	void numericReply_376(KIRC::Message &msg);
 
 	void numericReply_401(KIRC::Message &msg);
 	void numericReply_406(KIRC::Message &msg);
+	void numericReply_422(KIRC::Message &msg);
 	void numericReply_433(KIRC::Message &msg);
 	void numericReply_464(KIRC::Message &msg);
 	void numericReply_471(KIRC::Message &msg);
@@ -480,6 +506,10 @@ private:
 	bool m_FailedNickOnLogin;
 	bool m_useSSL;
 
+	QValueList<KIRC::Entity *> m_entities;
+	KIRC::EntityPtr m_server;
+	KIRC::EntityPtr m_self;
+
 	QString m_VersionString;
 	QString m_UserString;
 	QString m_SourceString;
