@@ -3,7 +3,7 @@
                              -------------------
     begin                : mer jui 31 2002
     copyright            : (C) 2002 by Olivier Goffart
-    email                : ogoffart@tiscalinet.be
+    email                : ogoffart @ kde.org
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,6 +17,7 @@
 
 #include "msnfiletransfersocket.h"
 
+#include <stdlib.h>
 #include <math.h>
 
 //qt
@@ -32,7 +33,7 @@
 #include "kopetetransfermanager.h"
 #include "kopetecontact.h"
 #include "kopetemetacontact.h"
-#include "msnmessagemanager.h"
+#include "msnchatsession.h"
 #include "msnswitchboardsocket.h"
 #include "msnnotifysocket.h"
 #include "msnaccount.h"
