@@ -631,9 +631,9 @@ int MSNSwitchBoardSocket::sendCustomEmoticon(const QString &name, const QString
 
 			QString sha1d = QString(KCodecs::base64Encode(SHA1::hash(ar)));
 			QString size = QString::number( pictFile.size() );
-			QString all = "Creator" + m_account->accountId() +	"Size" + size + "Type3Location" + fi.fileName() + "FriendlyAAA=SHA1D" + sha1d;
+			QString all = "Creator" + m_account->accountId() +	"Size" + size + "Type2Location" + fi.fileName() + "FriendlyAAA=SHA1D" + sha1d;
 			QString sha1c = QString(KCodecs::base64Encode(SHA1::hashString(all.utf8())));
-			picObj = "<msnobj Creator=\"" + m_account->accountId() + "\" Size=\"" + size  + "\" Type=\"3\" Location=\""+ fi.fileName() + "\" Friendly=\"AAA=\" SHA1D=\""+sha1d+ "\" SHA1C=\""+sha1c+"\"/>";
+			picObj = "<msnobj Creator=\"" + m_account->accountId() + "\" Size=\"" + size  + "\" Type=\"2\" Location=\""+ fi.fileName() + "\" Friendly=\"AAA=\" SHA1D=\""+sha1d+ "\" SHA1C=\""+sha1c+"\"/>";
 
 			PeerDispatcher()->objectList.insert(picObj, filename);
 		}
@@ -671,14 +671,15 @@ int MSNSwitchBoardSocket::sendMsg( const Kopete::Message &msg )
 	config->setGroup( "MSN" );
 	if ( config->readBoolEntry( "exportEmoticons", false ) )
 	{
-		QMap<QString, QString> emap = Kopete::Emoticons::self()->emoticonAndPicList();
+		QMap<QString, QStringList> emap = Kopete::Emoticons::self()->emoticonAndPicList();
 
 		// Check the list for any custom emoticons
-		for (QMap<QString, QString>::const_iterator itr = emap.begin(); itr != emap.end(); itr++)
+		for (QMap<QString, QStringList>::const_iterator itr = emap.begin(); itr != emap.end(); itr++)
 		{
-			if ( msg.plainBody().contains(itr.key()) )
+			for ( QStringList::const_iterator itr2 = itr.data().constBegin(); itr2 != itr.data().constEnd(); ++itr2 )
 			{
-				sendCustomEmoticon(itr.key(), itr.data());
+				if ( msg.plainBody().contains( *itr2 ) )
+					sendCustomEmoticon( *itr2, itr.key() );
 			}
 		}
 	}
