@@ -42,8 +42,6 @@ public:
 	/* Authorization settings */
 	void setRequireAuth( bool require );
 	bool requireAuth() const;
-	void setRespectRequireAuth( bool require );
-	bool respectRequireAuth() const;
 	
 	/* Hide IP Settings */
 	void setHideIP( bool hide );
@@ -53,7 +51,6 @@ private:
 	
 	bool m_webAware;
 	bool m_requireAuth;
-	bool m_respectRequireAuth;
 	bool m_hideIP;
 };
 
