@@ -41,6 +41,8 @@ protected:
 signals:
 	void gotBuddy(const QString&, const QString&, const QString&);
 	void stealthStatusChanged( const QString&, Yahoo::StealthStatus );
+private:
+	QString m_list;
 };
 
 #endif
