@@ -35,7 +35,7 @@
 // Yahoo Add Contact page
 YahooAddContact::YahooAddContact(YahooProtocol *owner, QWidget *parent, const char *name): AddContactPage(parent, name)
 {
-	kdDebug(14180) << "YahooAddContact::YahooAddContact(<owner>, <parent>, " << name << ")" << endl;
+	kdDebug(YAHOO_GEN_DEBUG) << "YahooAddContact::YahooAddContact(<owner>, <parent>, " << name << ")" << endl;
 
 	(new QVBoxLayout(this))->setAutoAdd(true);
 	theDialog = new YahooAddContactBase(this);
@@ -46,19 +46,19 @@ YahooAddContact::YahooAddContact(YahooProtocol *owner, QWidget *parent, const ch
 // Destructor
 YahooAddContact::~YahooAddContact()
 {
-	kdDebug(14180) << k_funcinfo << endl;
+	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
 }
 
 bool YahooAddContact::validateData()
 {
-	kdDebug(14180) << k_funcinfo << endl;
+	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
 
 	return !theDialog->contactID->text().isEmpty();
 }
 
 bool YahooAddContact::apply(Kopete::Account *theAccount, Kopete::MetaContact *theMetaContact)
 {
-	kdDebug(14180) << k_funcinfo << endl;
+	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
 
 	QString displayName = theDialog->contactID->text();
 	YahooAccount* myAccount = static_cast<YahooAccount*>(theAccount);
