@@ -103,8 +103,8 @@ namespace KPF
   {
     setAcceptDrops(true);
 
-    setFrameStyle(QFrame::Panel | QFrame::Sunken);
-    setLineWidth(1);
+    //setFrameStyle(QFrame::Panel | QFrame::Sunken);
+    //setLineWidth(1);
 
     connect
       (
@@ -230,6 +230,15 @@ namespace KPF
   {
     resetLayout();
   }
+    
+    void
+  Applet::moveEvent(QMoveEvent *)
+  {
+    QPtrListIterator<AppletItem> it(itemList_);
+
+    for (uint i = 0; it.current(); ++it, ++i)
+        it.current()->setBackground();
+  }
 
     void
   Applet::resetLayout()
