@@ -71,7 +71,8 @@ namespace KPF
        uint             listenPort,
        uint             bandwidthLimit  = Config::DefaultBandwidthLimit,
        uint             connectionLimit = Config::DefaultConnectionLimit,
-       bool             followSymlinks  = Config::DefaultFollowSymlinks
+       bool             followSymlinks  = Config::DefaultFollowSymlinks,
+       const QString  & serverName = QString::null
       );
 
       /**
@@ -136,7 +137,8 @@ namespace KPF
          uint     listenPort,
          uint     bandwidthLimit,
          uint     connectionLimit,
-         bool     followSymlinks
+         bool     followSymlinks,
+	 QString  serverName
         );
 
       void disableServer(DCOPRef);
