@@ -5,11 +5,19 @@
 
 static const char *devices[] = {
 #ifdef __FreeBSD__
+#if __FreeBSD_version > 600004
+  "/dev/cuad0",
+  "/dev/cuad1",
+  "/dev/cuad2",
+  "/dev/cuad3",
+  "/dev/cuad4",
+#else
   "/dev/cuaa0",
   "/dev/cuaa1",
   "/dev/cuaa2",
   "/dev/cuaa3",
   "/dev/cuaa4",
+#endif
 #elif defined(__NetBSD__)
   "/dev/tty00",                /* "normal" modem lines */
   "/dev/tty01",
@@ -48,6 +56,14 @@ static const char *devices[] = {
   "/dev/usb/ttyUSB1",
   "/dev/usb/ttyUSB2",
   "/dev/usb/ttyUSB3",
+  "/dev/ttyACM0",          /* USB stuff modems  with udev */
+  "/dev/ttyACM1",
+  "/dev/ttyACM2",
+  "/dev/ttyACM3",
+  "/dev/ttyUSB0",
+  "/dev/ttyUSB1",
+  "/dev/ttyUSB2",
+  "/dev/ttyUSB3",  
   "/dev/usb/tts/0",          /* USB stuff modems with devfs*/
   "/dev/usb/tts/1",
   "/dev/usb/tts/2",
@@ -64,6 +80,10 @@ static const char *devices[] = {
   "/dev/ttySL1",
   "/dev/ttySL2",
   "/dev/ttySL3",  
+  "/dev/ttySHSF0",
+  "/dev/ttySHSF1",
+  "/dev/ttySHSF2",
+  "/dev/ttySHSF3",  /* necessary for conexant modem which use hsfserial commercial module */
 #elif defined(__svr4__)
   "/dev/cua/a",
   "/dev/cua/b",
