@@ -15,16 +15,18 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <qpainter.h>
 #include <qcombobox.h>
 #include <qfile.h>
+#include <qheader.h>
+
+#include <kcalendarsystem.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <klistview.h>
-#include <qcombobox.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
 
@@ -32,7 +34,23 @@
 #include "export.h"
 #include <qstringlist.h>
 
-static void formatBytes(int bytes, QString &result) {
+static void formatBytes(double bytes, QString &result) {
+  if(bytes < 1024)
+    result.setNum(bytes);
+  else if(bytes < 1024*1024)
+    result = i18n("%1 KB").arg(KGlobal::locale()->formatNumber((float)bytes / 1024.0, 1));
+  else
+    result = i18n("%1 MB").arg(KGlobal::locale()->formatNumber((float)bytes / 1024.0 / 1024.0, 1));
+}
+ 
+static void formatBytesMonth(double bytes, QString &result) {
+
+  int day, days;
+  day = QDate::currentDate().day();
+  days = QDate::currentDate().daysInMonth();
+
+  bytes = (bytes / day) * days;
+
   if(bytes < 1024)
     result.setNum(bytes);
   else if(bytes < 1024*1024)
@@ -54,6 +72,37 @@ static void formatDuration(int seconds, QString &result) {
         .arg((seconds % 3600)/60)
         .arg(sec);
 }
+ 
+static void formatDurationMonth(int seconds, QString &result) {
+
+	int day, days;
+	day = QDate::currentDate().day();
+	days = QDate::currentDate().daysInMonth();
+
+	seconds = (seconds / day) * days;
+
+	QString sec;
+	sec.sprintf("%02d", seconds%60);
+	if(seconds < 60)
+		result = i18n("%1s").arg(sec);
+	else if(seconds < 3600)
+		result = i18n("%1m %2s").arg(seconds/60).arg(sec);
+	else
+		result = i18n("%1h %2m %3s")
+			.arg(seconds/3600)
+			.arg((seconds % 3600)/60)
+			.arg(sec);
+}
+
+static void costsMonth(double costs, double &result) {
+
+	int day, days;
+	day = QDate::currentDate().day();
+	days = QDate::currentDate().daysInMonth();
+
+	result = (costs / day) * days;
+
+}
 
 class LogListItem : public QListViewItem {
 public:
@@ -71,7 +120,7 @@ public:
 			  int column, int width, int alignment );
 
     virtual QString key(int, bool) const;
-private:
+
     LogInfo *li;
 };
 
@@ -81,10 +130,10 @@ void LogListItem::paintCell( QPainter *p, const QColorGroup & cg,
   QListViewItem::paintCell(p, cg, column, width, alignment);
 
   // double line above sum
-  if(!li) {
-    p->drawLine(0, 0, width, 0);
-    p->drawLine(0, 2, width, 2);
-  }
+  //if(!li) {
+   // p->drawLine(0, 0, width, 0);
+    //p->drawLine(0, 2, width, 2);
+  //}
 }
 
 QString LogListItem::key(int c, bool ascending) const
@@ -109,10 +158,10 @@ QString LogListItem::key(int c, bool ascending) const
     k.sprintf("%012.2f", li->sessionCosts());
     break;
   case 6:
-    k.sprintf("%012d", li->bytesIn());
+    k.sprintf("%012f", li->bytesIn());
     break;
   case 7:
-    k.sprintf("%012d", li->bytesOut());
+    k.sprintf("%012f", li->bytesOut());
     break;
   }
   return k;
@@ -141,10 +190,30 @@ MonthlyWidget::MonthlyWidget(QWidget *parent) :
   lv->setColumnAlignment(7, AlignRight);
   lv->setAllColumnsShowFocus(true);
   lv->setShowSortIndicator(true);
-  lv->setItemMargin(2);
+  lv->setItemMargin(1);
   lv->setSorting(1);
-  lv->setMinimumWidth(320);
-  lv->setMinimumHeight(200);
+  lv->setMinimumWidth(180);
+  lv->setMinimumHeight(280);
+  lv->setSelectionMode(QListView::Extended);
+  selectionItem = 0L;
+  connect(lv, SIGNAL(selectionChanged()), SLOT(slotSelectionChanged()));
+
+  lv2 = new KListView(this);
+  lv2->addColumn(i18n("Connection"));
+  lv2->addColumn(i18n("Duration"));
+  lv2->addColumn(i18n("Costs"));
+  lv2->addColumn(i18n("Bytes In"));
+  lv2->addColumn(i18n("Bytes Out"));
+  lv2->setColumnAlignment(1, AlignRight);
+  lv2->setColumnAlignment(2, AlignRight);
+  lv2->setColumnAlignment(3, AlignRight);
+  lv2->setColumnAlignment(4, AlignRight);
+  lv2->setAllColumnsShowFocus(true);
+  lv2->setSorting(-1);
+  lv2->setItemMargin(2);
+  lv2->setMaximumHeight(100);
+  lv2->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
+  lv2->setSelectionMode(QListView::NoSelection);
 
   title = new QLabel("X", this);
   QFont f = title->font();
@@ -160,12 +229,12 @@ MonthlyWidget::MonthlyWidget(QWidget *parent) :
 	  this, SLOT(slotConnections(int)));
 
   bbox = new KButtonBox(this, Qt::Vertical);
-  prev = bbox->addButton(i18n("Prev Month"));
-  next = bbox->addButton(i18n("Next Month"));
+  prev = bbox->addButton(i18n("&Prev Month"));
+  next = bbox->addButton(i18n("&Next Month"));
   bbox->addStretch(1);
-  today = bbox->addButton(i18n("Current Month"));
+  today = bbox->addButton(i18n("C&urrent Month"));
   bbox->addStretch(1);
-  exportBttn = bbox->addButton(i18n("Export..."));
+  exportBttn = bbox->addButton(i18n("&Export..."));
 
   connect(prev, SIGNAL(released()),
 	  this, SLOT(prevMonth()));
@@ -186,15 +255,23 @@ MonthlyWidget::MonthlyWidget(QWidget *parent) :
 void MonthlyWidget::layoutWidget() {
   if(tl)
     delete tl;
-  tl = new QVBoxLayout(this, 10, 10);
-  tl->addWidget(title);
-  tl->addWidget(cboConnections, 1);	// add the combo box
-
-  QHBoxLayout *l1 = new QHBoxLayout;
-  tl->addLayout(l1, 1);
-  l1->addWidget(lv, 1);
-  l1->addWidget(bbox);
 
+  tl = new QGridLayout(this, 1, 1, 11, 16, "MainLayout");
+  tl->addWidget(title, 0, 0);
+  tl->addWidget(cboConnections, 0, 1);
+  QLabel *l = new QLabel(this);
+  l->setText(i18n("Statistics:"));
+  QFont f2 = l->font();
+  f2.setPointSize(f2.pointSize() + 1);
+  f2.setBold(TRUE);
+  l->setFont(f2);
+  l->setFixedHeight(l->sizeHint().height());
+  l->setAlignment( AlignLeft );
+  tl->addWidget(l, 5, 0);
+  tl->addWidget(bbox, 1, 2);
+  tl->addMultiCellWidget(lv, 1, 4, 0, 1);
+  tl->addMultiCellWidget(lv2, 6, 6, 0, 1);
+      
   tl->activate();
 }
 
@@ -203,27 +280,26 @@ int bestlen(QWidget *w, const char *s) {
 }
 
 void MonthlyWidget::plotMonth() {
-  QStringList months;
-  for (int i=1; i<13; i++)
-      months.append(KGlobal::locale()->monthName(i, false/*short*/));
-
-  // current showed month
-  currMonth = months[_month-1];
-
   // name of the current connection
   QString con;
 
   // for collecting monthly statistics
   int count = 0;
   double costs = 0;
-  int bin = 0, bout = 0;
+  double bin = 0, bout = 0;
   int duration = 0;
   lv->clear();
+  selectionItem = 0L;
+  lv2->clear();
+
+  const KCalendarSystem * calendar = KGlobal::locale()->calendar();
+  QDate startDate = periodeFirst();
 
   for(int i = 0; i < (int)logList.count(); i++) {
     LogInfo *li = logList.at(i);
 
-    if(li->from().date().month() == _month && li->from().date().year() == _year) {
+    QDate logDate = li->from().date();
+    if ( periodeFirst() <= logDate && periodeLast() >= logDate ) {
       // get connection name for this line
       con = li->connectionName();
 
@@ -310,23 +386,53 @@ void MonthlyWidget::plotMonth() {
 
     QString s_costs(KGlobal::locale()->formatMoney(costs, QString::null, 2));
 
-    (void) new LogListItem(0, lv,
-			   i18n("%n connection", "%n connections", count),
+    selectionItem =  new LogListItem(0, lv2,
+			   i18n("Selection (%n connection)", "Selection (%n connections)", 0),
 			   QString::null, QString::null, QString::null,
-			   s_duration, s_costs, _bin, _bout);
+			   QString::null, QString::null, QString::null, QString::null);
+    (void) new LogListItem(0, lv2,
+			   i18n("%n connection", "%n connections", count),
+			   s_duration, s_costs, _bin, _bout, QString::null, QString::null, QString::null);
+
+	const KCalendarSystem * calendar = KGlobal::locale()->calendar();
+
+	if(calendar->month(periodeFirst()) == calendar->month(QDate::currentDate())) {
+
+	QString m_bin, m_bout;
+
+    if(bin < 0)
+      _bin = i18n("n/a");
+    else
+	formatBytesMonth(bin, m_bin);
+
+    if(bout < 0)
+      _bout = i18n("n/a");
+    else
+	formatBytesMonth(bout, m_bout);
+
+    QString m_duration;
+    formatDurationMonth(duration, m_duration);
+
+	costsMonth(costs, costs);
+    QString m_costs(KGlobal::locale()->formatMoney(costs, QString::null, 2));
+
+    (void) new QListViewItem(lv2, selectionItem,
+			   i18n("Monthly estimates"), m_duration, m_costs, m_bin, m_bout,
+			   QString::null, QString::null, QString::null);
+	}
   }
 
   QString t;
   if(lv->childCount() > 0) {
     exportBttn->setEnabled(true); // export possibility
     t = i18n("Connection log for %1 %2")
-	      .arg(months[_month-1])
-	      .arg(_year);
+	      .arg(calendar->monthName(startDate))
+	      .arg(calendar->year(startDate));
   } else {
     exportBttn->setEnabled(false); // nothing to export
     t = i18n("No connection log for %1 %2 available")
-	      .arg(months[_month-1])
-	      .arg(_year);
+	      .arg(calendar->monthName(startDate))
+	      .arg(calendar->year(startDate));
   }
 
   title->setText(t);
@@ -337,31 +443,30 @@ void MonthlyWidget::slotConnections(int) {
 }
 
 void MonthlyWidget::nextMonth() {
-  _month++;
-  if(_month == 13) {
-    _month = 1;
-    _year++;
-  }
+  m_periodeFirst = KGlobal::locale()->calendar()->addMonths(m_periodeFirst, 1);
+
   plotMonth();
 }
 
 void MonthlyWidget::prevMonth() {
-  _month--;
-  if(_month == 0) {
-    _month = 12;
-    _year--;
-  }
+  m_periodeFirst = KGlobal::locale()->calendar()->addMonths(m_periodeFirst, -1);
+
   plotMonth();
 }
 
 void MonthlyWidget::currentMonth() {
-  _month = QDate::currentDate().month();
-  _year  = QDate::currentDate().year();
+  const KCalendarSystem * calendar = KGlobal::locale()->calendar();
+  QDate dt = QDate::currentDate();
+  calendar->setYMD(m_periodeFirst, calendar->year(dt), calendar->month(dt), 1);
+
   plotMonth();
 }
 
 void MonthlyWidget::exportWizard() {
-  QString date = QString(currMonth+"-%1").arg(_year);  // e.g.: June-2001
+  const KCalendarSystem * calendar = KGlobal::locale()->calendar();
+  QString date = QString::fromLatin1("%1-%2") // e.g.: June-2001
+    .arg(calendar->monthName(periodeFirst()))
+    .arg(calendar->year(periodeFirst()));
 
   ExportWizard *wizard = new ExportWizard(0, date);
   wizard->exec();
@@ -369,7 +474,7 @@ void MonthlyWidget::exportWizard() {
     return;
   }
   if (QFile::exists(wizard->filename)) {  // overwrite?
-    if (KMessageBox::Continue!=KMessageBox::warningContinueCancel(0, i18n("A document with this name already exists."), i18n("Overwrite file?"), i18n("Overwrite") /*, true*/)) { // no
+    if (KMessageBox::Continue!=KMessageBox::warningContinueCancel(0, i18n("A document with this name already exists."), i18n("Overwrite file?"), i18n("&Overwrite") /*, true*/)) { // no
       return;
     }
   }
@@ -396,13 +501,14 @@ void MonthlyWidget::exportWizard() {
   // for collecting monthly statistics
   int count = 0;
   double costs = 0;
-  int bin = 0, bout = 0;
+  double bin = 0, bout = 0;
   int duration = 0;
 
   for(int i = 0; i < (int)logList.count(); i++) {
     LogInfo *li = logList.at(i);
 
-    if(li->from().date().month() == _month && li->from().date().year() == _year) {
+    QDate logDate = li->from().date();
+    if (periodeFirst() <= logDate && periodeLast() >= logDate ) {
       // get connection name for this line
       con = li->connectionName();
 
@@ -466,9 +572,36 @@ void MonthlyWidget::exportWizard() {
       // call export method
       exportIFace->addDataline(con, day, s_lifrom, s_liuntil, s_duration,
 			       s_costs, _bin, _bout);
+
     }
   }
 
+	if(calendar->month(periodeFirst()) == calendar->month(QDate::currentDate())) {
+
+	QString m_bin, m_bout;
+	if(bin < 0)
+		m_bin = i18n("n/a");
+	else
+		formatBytesMonth(bin, m_bin);
+
+	if(bout < 0)
+		m_bout = i18n("n/a");
+	else
+		formatBytesMonth(bout, m_bout);
+
+	QString m_duration;
+	formatDurationMonth(duration, m_duration);
+
+	costsMonth(costs, costs);
+	QString m_costs(KGlobal::locale()->formatMoney(costs, QString::null, 2));
+
+	QString datetime = KGlobal::locale()->formatDateTime( QDateTime::currentDateTime(), true);
+
+	exportIFace->addEmptyLine();
+	exportIFace->addDataline(i18n("Monthly estimates (%1)").arg(datetime), 
+		QString::null, QString::null, QString::null, m_duration, m_costs, m_bin, m_bout);
+	}
+
   if(count) {
     QString _bin, _bout, _b;
 
@@ -501,7 +634,7 @@ void MonthlyWidget::exportWizard() {
 
     // write buffer to file and close file
     if (!exportIFace->closeFile())  {
-      KMessageBox::sorry(0, i18n("An error occurred while trying to write to this file"), i18n("Sorry"), true);
+      KMessageBox::sorry(0, i18n("An error occurred while trying to write to this file."), i18n("Sorry"), true);
       delete exportIFace;
       return;
     }
@@ -510,6 +643,87 @@ void MonthlyWidget::exportWizard() {
   delete exportIFace;
 }
 
+QDate MonthlyWidget::periodeFirst() const
+{
+  return m_periodeFirst;
+}
 
+QDate MonthlyWidget::periodeLast() const
+{
+  const KCalendarSystem * calendar = KGlobal::locale()->calendar();
+
+  // One month minus one day
+  return calendar->addDays(calendar->addMonths(m_periodeFirst, 1), -1);
+}
+
+void MonthlyWidget::slotSelectionChanged()
+{
+  if (selectionItem)
+  {
+    int count = 0;
+    double costs = 0;
+    double bin = 0, bout = 0;
+    int duration = 0;
+    LogListItem *item;
+    LogInfo *li;
+    QListViewItemIterator it(lv);
+    while ( it.current() )
+    {
+      item = dynamic_cast<LogListItem*>(it.current());
+      if ( item && item->isSelected() && item->li)
+      {
+        li = item->li;
+        costs += li->sessionCosts();
+        if(bin >= 0) {
+          if(li->bytesIn() < 0)
+            bin = -1;
+          else
+            bin += li->bytesIn();
+        }
+
+        if(bout >= 0) {
+          if(li->bytesOut() < 0)
+            bout = -1;
+          else
+            bout += li->bytesOut();
+        }
+
+        duration += li->from().secsTo(li->until());
+        count++;
+      }
+      ++it;
+    }
+    if(count)
+    {
+      QString _bin, _bout, _b;
+
+      if(bin < 0)
+        _bin = i18n("n/a");
+      else
+        formatBytes(bin, _bin);
+
+      if(bout < 0)
+        _bout = i18n("n/a");
+      else
+        formatBytes(bout, _bout);
+
+      if(bin < 0 || bout < 0)
+        _b = i18n("n/a");
+      else
+        formatBytes(bout + bin, _b);
+
+      QString s_duration;
+      formatDuration(duration,
+                    s_duration);
+
+      QString s_costs(KGlobal::locale()->formatMoney(costs, QString::null, 2));
+      selectionItem->setText(0, i18n("Selection (%n connection)", "Selection (%n connections)", count));
+      selectionItem->setText(1, s_duration);
+      selectionItem->setText(2, s_costs);
+      selectionItem->setText(3, _bin);
+      selectionItem->setText(4, _bout);
+    }
+  }
+}
 
 #include "monthly.moc"
