@@ -1,7 +1,7 @@
 /* -*- C++ -*-
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: ruleset.cpp,v 1.29 2002/11/02 11:30:38 rysin Exp $
+ * $Id: ruleset.cpp 212185 2003-03-07 22:11:39Z waba $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -21,7 +21,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <stdlib.h>
@@ -241,7 +241,7 @@ bool RuleSet::parseEntries(QString s, int year,
 			   double costs, double len, double after)
 {
   // special rule: on() is the same as on(monday..sunday)
-  if(s == "")
+  if(s.isEmpty())
     s = "monday..sunday";
 
   while(s.length()) {
@@ -535,7 +535,7 @@ QTime RuleSet::beforeMidnight() const {
 
 int RuleSet::checkRuleFile(const QString &rulefile) {
   if(rulefile == NULL) {
-    fprintf(stderr, i18n("kppp: no rulefile specified\n").local8Bit());
+    fputs(i18n("kppp: no rulefile specified\n").local8Bit(), stderr);
     return 1;
   }
 
@@ -546,7 +546,7 @@ int RuleSet::checkRuleFile(const QString &rulefile) {
   }
 
   if(rulefile.right(4) != ".rst") {
-    fprintf(stderr, i18n("kppp: rulefiles must have the extension \".rst\"\n").local8Bit());
+    fputs(i18n("kppp: rulefiles must have the extension \".rst\"\n").local8Bit(), stderr);
     return 1;
   }
 
@@ -555,7 +555,7 @@ int RuleSet::checkRuleFile(const QString &rulefile) {
   fl.close();
 
   if(err == -1) {
-    fprintf(stderr, i18n("kppp: error parsing the ruleset\n").local8Bit());
+    fputs(i18n("kppp: error parsing the ruleset\n").local8Bit(), stderr);
     return 1;
   }
 
@@ -566,16 +566,16 @@ int RuleSet::checkRuleFile(const QString &rulefile) {
 
   // check for the existance of a default rule
   if((r.default_costs < 0) || (r.default_len < 0)) {
-    fprintf(stderr, i18n("kppp: rulefile does not contain a default rule\n").local8Bit());
+    fputs(i18n("kppp: rulefile does not contain a default rule\n").local8Bit(), stderr);
     return 1;
   }
 
   if(r.name().length() == 0) {
-    fprintf(stderr, i18n("kppp: rulefile does not contain a \"name=...\" line\n").local8Bit());
+    fputs(i18n("kppp: rulefile does not contain a \"name=...\" line\n").local8Bit(), stderr);
     return 1;
   }
 
-  fprintf(stderr, i18n("kppp: rulefile is ok\n").local8Bit());
+  fputs(i18n("kppp: rulefile is ok\n").local8Bit(), stderr);
   return 0;
 }
 
