@@ -16,25 +16,24 @@
  ***************************************************************************/
 
 #include "kvncview.h"
-#include "vnchostpreferences.h"
+#include "vncprefs.h"
 #include "vnchostpref.h"
+
+#include <kapplication.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kinstance.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kkeynative.h>
 #include <kpassdlg.h>
+#include <kdialogbase.h>
+#include <kwallet.h>
+
 #include <qdatastream.h>
 #include <dcopclient.h>
+#include <qclipboard.h>
 #include <qbitmap.h>
-#include <qlineedit.h>
-#include <qdialog.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
 #include <qmutex.h>
+#include <qvbox.h>
 #include <qwaitcondition.h>
 
 #include "vncviewer.h"
@@ -53,6 +52,9 @@ Display* dpy;
 
 static KVncView *kvncview;
 
+//Passwords and KWallet data
+extern KWallet::Wallet *wallet;
+bool useKWallet = false;
 static QCString password;
 static QMutex passwordLock;
 static QWaitCondition passwordWaiter;
@@ -66,6 +68,7 @@ KVncView::KVncView(QWidget *parent,
 		   int _port,
 		   const QString &_password,
 		   Quality quality,
+		   DotCursorState dotCursorState,
 		   const QString &encodings) :
   KRemoteView(parent, name, Qt::WResizeNoErase | Qt::WRepaintNoErase | Qt::WStaticContents),
   m_cthread(this, m_wthread, m_quitFlag),
@@ -78,7 +81,8 @@ KVncView::KVncView(QWidget *parent,
   m_buttonMask(0),
   m_host(_host),
   m_port(_port),
-  m_dontSendCb(false)
+  m_dontSendCb(false),
+  m_cursorState(dotCursorState)
 {
 	kvncview = this;
 	password = _password.latin1();
@@ -102,22 +106,33 @@ KVncView::KVncView(QWidget *parent,
 		configureApp(quality, encodings);
 }
 
-void KVncView::showDotCursor(bool show) {
-	bool s = show;
-	if (m_enableClientCursor)
-		s = false;
-	if (show == m_cursorEnabled)
+void KVncView::showDotCursor(DotCursorState state) {
+	if (state == m_cursorState)
 		return;
 
-	m_cursorEnabled = s;
+	m_cursorState = state;
 	showDotCursorInternal();
 }
 
+DotCursorState KVncView::dotCursorState() const {
+	return m_cursorState;
+}
+
 void KVncView::showDotCursorInternal() {
-	if (!m_cursorEnabled)
-		setCursor(QCursor(Qt::BlankCursor));
-	else
+	switch (m_cursorState) {
+	case DOT_CURSOR_ON:
 		setCursor(m_cursor);
+		break;
+	case DOT_CURSOR_OFF:
+		setCursor(QCursor(Qt::BlankCursor));
+		break;
+	case DOT_CURSOR_AUTO:
+		if (m_enableClientCursor)
+			setCursor(QCursor(Qt::BlankCursor));
+		else
+			setCursor(m_cursor);
+		break;
+	}
 }
 
 QString KVncView::host() {
@@ -175,10 +190,8 @@ void KVncView::configureApp(Quality q, const QString specialEncodings) {
 	appData.rawDelay = 0;
 	appData.copyRectDelay = 0;
 
-	if (m_enableClientCursor)
-		m_cursorEnabled = false;
-	else
-		m_cursorEnabled = appData.dotCursor ? true : false;
+	if (!appData.dotCursor)
+		m_cursorState = DOT_CURSOR_OFF;
 	showDotCursorInternal();
 }
 
@@ -206,42 +219,64 @@ bool KVncView::checkLocalKRfb() {
 
 	setStatus(REMOTE_VIEW_DISCONNECTED);
 	KMessageBox::error(0,
-			   i18n("It is not possible to connect to a local Desktop Sharing service."),
+			   i18n("It is not possible to connect to a local desktop sharing service."),
 			   i18n("Connection Failure"));
 	emit disconnectedError();
 	return false;
 }
 
+bool KVncView::editPreferences( HostPrefPtr host )
+{
+	SmartPtr<VncHostPref> hp( host );
+
+	int ci = hp->quality();
+	bool kwallet = hp->useKWallet();
+
+	// show preferences dialog
+	KDialogBase *dlg = new KDialogBase( 0L, "dlg", true,
+		i18n( "VNC Host Preferences for %1" ).arg( host->host() ),
+		KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true );
+
+	QVBox *vbox = dlg->makeVBoxMainWidget();
+	VncPrefs *prefs = new VncPrefs( vbox );
+	QWidget *spacer = new QWidget( vbox );
+	vbox->setStretchFactor( spacer, 10 );
+
+	prefs->setQuality( ci );
+	prefs->setShowPrefs(true);
+	prefs->setUseKWallet(kwallet);
+
+	if ( dlg->exec() == QDialog::Rejected )
+		return false;
+
+	ci = prefs->quality();
+	hp->setAskOnConnect(prefs->showPrefs());
+	hp->setQuality(ci);
+	hp->setUseKWallet(prefs->useKWallet());
+
+	delete dlg;
+	return true;
+}
+
 bool KVncView::start() {
 
 	if (!checkLocalKRfb())
 		return false;
 
 	if (!appDataConfigured) {
-		KConfig *config = KApplication::kApplication()->config();
-		config->setGroup("VncDefaultSettings");
-		bool showPrefs = config->readBoolEntry("vncShowHostPreferences", true);
 
-		HostPreferences hps(config);
+		HostPreferences *hps = HostPreferences::instance();
 		SmartPtr<VncHostPref> hp =
-			SmartPtr<VncHostPref>(hps.createHostPref(m_host,
+			SmartPtr<VncHostPref>(hps->createHostPref(m_host,
 								 VncHostPref::VncType));
-		int ci = hp->quality();
-		if (showPrefs && hp->askOnConnect()) {
-			// show preferences dialog
-			VncHostPreferences vhp(0, "VncHostPreferencesDialog", true);
-			vhp.setCaption(i18n("VNC Host Preferences for %1").arg(m_host));
-			vhp.qualityCombo->setCurrentItem(ci);
-			vhp.nextStartupCheckbox->setChecked(true);
-			if (vhp.exec() == QDialog::Rejected)
+		if (hp->askOnConnect()) {
+			if (!editPreferences(hp))
 				return false;
-
-			ci = vhp.qualityCombo->currentItem();
-			hp->setAskOnConnect(vhp.nextStartupCheckbox->isChecked());
-			hp->setQuality(ci);
-			hps.sync();
+			hps->sync();
 		}
 
+		int ci = hp->quality();
+
 		Quality quality;
 		if (ci == 0)
 			quality = QUALITY_HIGH;
@@ -255,6 +290,7 @@ bool KVncView::start() {
 		}
 
 		configureApp(quality);
+		useKWallet = hp->useKWallet();
 	}
 
 	setStatus(REMOTE_VIEW_CONNECTING);
@@ -272,11 +308,15 @@ KVncView::~KVncView()
 	freeResources();
 }
 
-bool KVncView::supportsScaling() {
+bool KVncView::supportsLocalCursor() const {
 	return true;
 }
 
-bool KVncView::scaling() {
+bool KVncView::supportsScaling() const {
+	return true;
+}
+
+bool KVncView::scaling() const {
 	return m_scaling;
 }
 
@@ -353,6 +393,13 @@ void KVncView::customEvent(QCustomEvent *e)
 			setMouseTracking(false);
 			emit disconnected();
 		}
+		else if (m_status == REMOTE_VIEW_PREPARING) {
+			//Login was successfull: Write KWallet password if necessary.
+			if ( useKWallet && !password.isNull() && wallet && wallet->isOpen() && !wallet->hasEntry(host())) {
+				wallet->writePassword(host(), password);
+			}
+			delete wallet; wallet=0;
+		}
 	}
 	else if (e->type() == PasswordRequiredEventType) {
 		emit showingPasswordDialog(true);
@@ -366,6 +413,42 @@ void KVncView::customEvent(QCustomEvent *e)
 		passwordWaiter.wakeAll();
 		passwordLock.unlock();
 	}
+	else if (e->type() == WalletOpenEventType) {
+		QString krdc_folder = "KRDC-VNC";
+		emit showingPasswordDialog(true); //Bad things happen if you don't do this.
+
+		// Bugfix: Check if wallet has been closed by an outside source
+		if ( wallet && !wallet->isOpen() ) {
+			delete wallet; wallet=0;
+		}
+
+		// Do we need to open the wallet?
+		if ( !wallet ) {
+			QString walletName = KWallet::Wallet::NetworkWallet();
+			wallet = KWallet::Wallet::openWallet(walletName);
+		}
+
+		if (wallet && wallet->isOpen()) {
+			bool walletOK = wallet->hasFolder(krdc_folder);
+			if (walletOK == false) {
+				walletOK = wallet->createFolder(krdc_folder);
+			}
+	
+			if (walletOK == true) {
+				wallet->setFolder(krdc_folder);
+				QString newPass;
+				if ( wallet->hasEntry(kvncview->host()) && !wallet->readPassword(kvncview->host(), newPass) ) {
+					password=newPass.latin1();
+				}
+			}
+		}
+
+		passwordLock.lock(); // to guarantee that thread is waiting
+		passwordWaiter.wakeAll();
+		passwordLock.unlock();
+
+		emit showingPasswordDialog(false);
+	}
 	else if (e->type() == FatalErrorEventType) {
 		FatalErrorEvent *fee = (FatalErrorEvent*) e;
 		setStatus(REMOTE_VIEW_DISCONNECTED);
@@ -401,6 +484,10 @@ void KVncView::customEvent(QCustomEvent *e)
 					   i18n("Connection Failure"));
 			break;
 		case ERROR_AUTHENTICATION:
+			//Login failed: Remove wallet entry if there is one.
+			if ( useKWallet && wallet && wallet->isOpen() && wallet->hasEntry(host()) ) {
+				wallet->removeEntry(host());
+			}
 			KMessageBox::error(0,
 					   i18n("Authentication failed. Connection aborted."),
 					   i18n("Authentication Failure"));
@@ -427,7 +514,9 @@ void KVncView::customEvent(QCustomEvent *e)
 	else if (e->type() == MouseStateEventType) {
 		MouseStateEvent *mse = (MouseStateEvent*) e;
 		emit mouseStateChanged(mse->x(), mse->y(), mse->buttonMask());
-		showDotCursor(m_plom.handlePointerEvent(mse->x(), mse->y()));
+		bool show = m_plom.handlePointerEvent(mse->x(), mse->y());
+		if (m_cursorState != DOT_CURSOR_ON)
+			showDotCursor(show ? DOT_CURSOR_AUTO : DOT_CURSOR_OFF);
 	}
 }
 
@@ -641,32 +730,57 @@ void KVncView::unlockFramebuffer() {
 void KVncView::enableClientCursor(bool enable) {
 	if (enable) {
 		m_enableFramebufferLocking = true; // cant be turned off
-		showDotCursor(false);
 	}
-	else
-		showDotCursor(appData.dotCursor);
 	m_enableClientCursor = enable;
-
+	lockFramebuffer();
+	showDotCursorInternal();
+	unlockFramebuffer();
 }
 
+/*!
+	\brief Get a password for this host.
+	Tries to get a password from the url or wallet if at all possible. If
+	both of these fail, it then asks the user to enter a password.
+	\note Lots of dialogs can be popped up during this process. The thread
+	locks and signals are there to protect against deadlocks and other
+	horribleness. Be careful making changes here. 
+*/
 int getPassword(char *passwd, int pwlen) {
-	int retV = 1;
+	int retV = 0;
 
+	//Prepare the system
 	passwordLock.lock();
-	if (password.isNull()) {
-		QApplication::postEvent(kvncview, new PasswordRequiredEvent());
-		passwordWaiter.wait(&passwordLock);
-	}
-	if (!password.isNull())
-		strncpy(passwd, (const char*)password, pwlen);
-	else {
-		passwd[0] = 0;
-		retV = 0;
-	}
-	passwordLock.unlock();
 
-	if (!retV)
-		kvncview->startQuitting();
+	//Try #1: Did the user give a password in the URL?
+	if (!password.isNull()) {
+		retV = 1; //got it!
+	}
+
+	//Try #2: Is there something in the wallet?
+	if ( !retV && useKWallet ) {
+		QApplication::postEvent(kvncview, new WalletOpenEvent());
+		passwordWaiter.wait(&passwordLock); //block
+		if (!password.isNull()) retV = 1; //got it!
+	}
+
+	//Last try: Ask the user
+	if (!retV) {
+		QApplication::postEvent(kvncview, new PasswordRequiredEvent());
+		passwordWaiter.wait(&passwordLock); //block
+		if (!password.isNull()) retV = 1; //got it!
+	}
+
+	//Process the password if we got it, clear it if we didn't
+	if (retV) {
+		strncpy(passwd, (const char*)password, pwlen);
+	} else {
+		passwd[0] = 0;
+	}
+
+	//Pack up and go home
+	passwordLock.unlock();
+	if (!retV) kvncview->startQuitting();
+
 	return retV;
 }
 
