@@ -14,12 +14,13 @@
 
 class PageGeneral;
 class PageColors;
+class PageIRCColors;
 class PageStartup;
-/*
 class PageRMBMenu;
 class PageServChan;
-*/
-
+class PageAutoConnect;
+class PageLooknFeel;
+class PageShortcuts;
 
 class PageFont; /* For the font settings */
 
@@ -43,10 +44,19 @@ signals:
 
 private:
     PageColors   *pageColors;
+    PageIRCColors   *pageIRCColors;
     PageGeneral  *pageGeneral;
-//    PageRMBMenu  *pageRMBMenu;
+    PageRMBMenu  *pageRMBMenu;
     PageStartup  *pageStartup;
-//    PageServChan *pageServChan;
+    PageServChan *pageServChan;
+    PageAutoConnect *pageAutoConnect;
+    PageLooknFeel *pageLooknFeel;
+    PageShortcuts *pageShortcuts;
+
+    int pSCDirty;
+    int pACDirty;
+    int pLFDirty;
+    int pShortDirty;
 
     PageFont *pageFont; /* Font settings page */
     int dirty;
