@@ -4,10 +4,11 @@
 #include <qobject.h>
 #include <qframe.h>
 #include <qstring.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpopupmenu.h>
 
-struct SInfo {
+class SInfo {
+public:
   int length;
 };
 
@@ -21,6 +22,7 @@ public:
 
   void setString(QString);
   void mergeString(QString);
+  void mergeString(QString, QColor);
 
   virtual void show();
   virtual void hide();
@@ -53,49 +55,51 @@ protected:
   virtual void iconify();
 
 
+private:
 
-private: 
-  QString ring; 
-  QString display;
-  QList<SInfo> StrInfo;
-  QFont ourFont;
+    QString stripCols(QString);
 
-  int onechar;
-  int chars;
-  int descent;
-  
-  int tickStep;
-  int cOffset;
+    QStringList strlist;   /* everything left to parse */
+    QStringList strbuffer; /* fifo of the last 10 lines to scroll in scroll constantly mode */
+    QStringList tipbuffer; /* 5 lines for the tooltip */
+    QString currentStr;   /* the string we are currently parsing */
 
-  int tickRate;
+    QFont ourFont;
 
-  int pHeight;
-  
-  int currentChar;
+    int onechar;
+    int chars;
+    int descent;
 
-  void startTicker();
-  void stopTicker();
+    int tickStep;
+    int cOffset;
 
-  bool bScrollConstantly;
-  int iScrollItem;
-  bool bAtEnd;
+    int tickRate;
 
-  QPixmap *pic;
+    int pHeight;
 
-  QPopupMenu *popup;
+    int currentChar;
 
-  /*
-   * Drawing settings and variables
-   */
-  bool bold;
-  bool underline;
-  bool italics;
-  QColor defbg;
-  QColor deffg;
-  QColor bg;
-  QColor fg;
+    void startTicker();
+    void stopTicker();
 
+    bool bScrollConstantly;
+    int iScrollItem;
+    bool bAtEnd;
 
+    QPixmap *pic;
+
+    QPopupMenu *popup;
+
+    /*
+     * Drawing settings and variables
+     */
+    bool bold;
+    bool underline;
+    bool italics;
+    QColor defbg;
+    QColor deffg;
+    QColor bg;
+    QColor fg;
 };
 
 #endif // KSTICKER_H
