@@ -8,12 +8,12 @@ public:
     Timer( dccManager *view )
         : m_view( view )
     {
-        m_it = m_view->newSendItem("test", "boren", dccItem::dccOffer, 123523);
-        m_view->newSendItem("test2", "boren", dccItem::dccOffer, 123523);
-        m_view->newSendItem("test3", "boren", dccItem::dccOffer, 123523);
-        m_view->newGetItem("test4", "boren", dccItem::dccOffer, 123523);
-        m_view->newGetItem("test4", "boren", dccItem::dccOffer, 123523);
-        m_view->newGetItem("test4", "boren", dccItem::dccOffer, 123523);
+        m_it = m_view->newSendItem("test", "boren", dccItem::dccSentOffer, 123523);
+        m_view->newSendItem("test2", "boren", dccItem::dccSentOffer, 123523);
+        m_view->newSendItem("test3", "boren", dccItem::dccSentOffer, 123523);
+        m_view->newGetItem("test4", "boren", dccItem::dccGotOffer, 123523);
+        m_view->newGetItem("test4", "boren", dccItem::dccGotOffer, 123523);
+        m_view->newGetItem("test4", "boren", dccItem::dccGotOffer, 123523);
         bytes = 0;
         startTimer( 100 );
     }
