@@ -16,7 +16,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: ksparser.cpp 229726 2003-06-05 03:36:28Z asj $
+// $Id: ksparser.cpp 393645 2005-02-27 22:05:39Z staikos $
 
 #include <qstring.h>
 #include <qcolor.h>
@@ -32,6 +32,7 @@ QString KSParser::parse( const QString &message )
     QString res;
     m_tags.clear();
     m_attributes.clear();
+    m_beeped = false;
 
     for (unsigned int i = 0; i < message.length();)
     {
@@ -100,6 +101,9 @@ QString KSParser::parse( const QString &message )
                 case 'b':
                     res += toggleTag( "b" );
                     break;
+                case 'g':
+                    m_beeped = true;
+                    break;
                 case 'u':
                     res += toggleTag( "u" );
                     break;
