@@ -26,9 +26,6 @@ public slots:
   void highlighted(int);
   void selected(int);
 
-signals:
-  void outputMessage(int fd, PukeMessage *pm);
-
 protected:
   bool checkWidget();
 
