@@ -1,8 +1,8 @@
 #include "pobject.h"
 #include "commands.h"
-#include "../config.h"
 
-PObject::PObject(QObject *pobject, const char *name) /*FOLD00*/
+
+PObject::PObject(QObject *pobject, const char *name) 
   : QObject(pobject, name)
 {
   // Connect slots as needed
@@ -13,7 +13,7 @@ PObject::PObject(QObject *pobject, const char *name) /*FOLD00*/
   m_hasError = false;
 }
 
-PObject::~PObject() /*FOLD00*/
+PObject::~PObject() 
 {
   if(isDeleteAble())
     delete widget();
@@ -21,21 +21,21 @@ PObject::~PObject() /*FOLD00*/
   setWidget(0);
 }
 
-PObject *PObject::createWidget(CreateArgs &ca) /*fold00*/
+PObject *PObject::createWidget(CreateArgs &ca) 
 {
-  PObject *pw = new("PObject") PObject(ca.parent);
+  PObject *pw = new PObject(ca.parent);
   QObject *o;
   if(ca.parent != 0)
-    o = new("QObject") QObject(ca.parent->widget());
+    o = new QObject(ca.parent->widget());
   else
-    o = new("QObject") QObject();
+    o = new QObject();
   pw->setWidget(o);
   pw->setWidgetId(ca.pwI);
   pw->setPukeController(ca.pc);
   return pw;
 }
 
-void PObject::messageHandler(int fd, PukeMessage *pm) /*fold00*/
+void PObject::messageHandler(int fd, PukeMessage *pm) 
 {
   PukeMessage pmRet;
   if(pm->iCommand == PUKE_WIDGET_DELETE){
@@ -78,7 +78,7 @@ void PObject::messageHandler(int fd, PukeMessage *pm) /*fold00*/
   }
 }
 
-void PObject::setWidget(QObject *_o) /*FOLD00*/
+void PObject::setWidget(QObject *_o) 
 {
   // Disconnect everything from the object we where listning too
   // Just in case it fires something off, we don't want to get it
@@ -94,25 +94,25 @@ void PObject::setWidget(QObject *_o) /*FOLD00*/
   }
 }
 
-QObject *PObject::widget() /*FOLD00*/
+QObject *PObject::widget() 
 {
-  //  kdDebug() << "PObject widget called" << endl;
+  //  kdDebug(5008) << "PObject widget called" << endl;
   return obj;
 }
 
-void PObject::setWidgetId(widgetId *pwI) /*fold00*/
+void PObject::setWidgetId(widgetId *pwI) 
 {
   wI = *pwI;
-  //  kdDebug() << "PObject: set widget id " << wI.iWinId << endl;
+  //  kdDebug(5008) << "PObject: set widget id " << wI.iWinId << endl;
 }
 
-widgetId PObject::widgetIden() /*fold00*/
+widgetId PObject::widgetIden() 
 {
-  //  kdDebug() << "PObject: called widget id " << wI.iWinId << endl;
+  //  kdDebug(5008) << "PObject: called widget id " << wI.iWinId << endl;
   return wI;
 }
 
-void PObject::swidgetDestroyed(){ /*FOLD00*/
+void PObject::swidgetDestroyed(){ 
   setWidget(0x0);
   if(manualTerm == FALSE){
     manTerm();
@@ -120,7 +120,7 @@ void PObject::swidgetDestroyed(){ /*FOLD00*/
   }
 }
 
-PukeController *PObject::controller() { /*FOLD00*/
+PukeController *PObject::controller() { 
   
   return pController;
 }
