@@ -6,15 +6,13 @@
 #include "pmessage.h"
 #include "controller.h"
 
-// Init and setup code
-extern "C" {
-PObject *createWidget(CreateArgs &ca);
-}
 
 class PObjFinder : public PObject
 {
   Q_OBJECT
- public:
+public:
+  static PObject *createWidget(CreateArgs &ca);
+
   PObjFinder ( PObject * parent );
   virtual ~PObjFinder ();
   
@@ -26,13 +24,10 @@ class PObjFinder : public PObject
 public slots:
   virtual void newObject(QObject *obj);
 
- signals:
-   void outputMessage(int fd, PukeMessage *pm);
-
 protected:
   bool checkWidget();
 
- private:
+private:
 };
 
 #endif
