@@ -2,7 +2,7 @@
 
  TopLevel IRC Channel/query Window
 
- $$Id: toplevel.cpp 288737 2004-02-17 16:11:56Z asj $$
+ $$Id: toplevel.cpp 437911 2005-07-23 14:56:02Z binner $$
 
  This is the main window with which the user interacts.  It handles
  both normal channel conversations and private conversations.
@@ -1601,7 +1601,7 @@ void KSircTopLevel::slotTextDropped( const QString& _text )
            if ( commands == Ask )
                 switch ( KMessageBox::questionYesNo( this, i18n(
                     "The text you pasted contains lines that start with /.\n"
-                    "Should they be interpreted as IRC commands?" ) ) )
+                    "Should they be interpreted as IRC commands?" ), QString::null, i18n("Interpret"), i18n("Do Not Interpret") ) )
                 {
                     case KMessageBox::Yes:
                         commands = Parse;
