@@ -18,53 +18,70 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifdef USE_SOLARIS
-#define BSD_COMP
-#endif
-
-#include "findnic.h"
-
-#include <stdio.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#ifdef USE_SOLARIS
-/* net/if.h is incompatible with STL on Solaris 2.6 and 2.8, redefine
-   map in the header file because we don't need it. -- Simon Josefsson */
-#define map junkmap
-#endif
-#include <net/if.h>
-#ifdef USE_SOLARIS
-#undef map
-#endif
-#include <sys/ioctl.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-
-#include <ksockaddr.h>
+#include <config.h>
 
 #ifdef HAVE_SYS_SOCKIO_H
 #include <sys/sockio.h>
 #endif
 
+#include <sys/types.h>
+#include <sys/param.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/socket.h>
+
+#ifdef USE_SOLARIS
+/* net/if.h is incompatible with STL on Solaris 2.6 - 2.8, redefine
+   map in the header file because we don't need it. -- Simon Josefsson */
+#define map junkmap
+#endif
+#  include <net/if.h>
+#ifdef USE_SOLARIS
+#undef map
+#endif
+
+#include <sys/ioctl.h>
+
+#ifndef	HAVE_STRUCT_SOCKADDR_SA_LEN
+	#undef HAVE_GETNAMEINFO
+	#undef HAVE_GETIFADDRS
+#endif
+
+#if defined(HAVE_GETNAMEINFO) && defined(HAVE_GETIFADDRS)
+	#include <ifaddrs.h>
+	#include <netdb.h>
+	#include <qstring.h>
+
+	QString flags_tos (unsigned int flags);
+#endif
+
+#include "findnic.h"
+
+#include <klocale.h>
+#include <ksockaddr.h>
+
 NICList* findNICs()
 {
    NICList* nl=new NICList;
    nl->setAutoDelete(true);
 
-	int sockfd = socket(AF_INET, SOCK_DGRAM, 0);
+#if !defined(HAVE_GETIFADDRS) && !defined(HAVE_GETNAMEINFO)
+
+   int sockfd = socket(AF_INET, SOCK_DGRAM, 0);
 
    char buf[8*1024];
    struct ifconf ifc;
-	ifc.ifc_len = sizeof(buf);
-	ifc.ifc_req = (struct ifreq *) buf;
-	int result=ioctl(sockfd, SIOCGIFCONF, &ifc);
+   ifc.ifc_len = sizeof(buf);
+   ifc.ifc_req = (struct ifreq *) buf;
+   int result=ioctl(sockfd, SIOCGIFCONF, &ifc);
 
    for (char* ptr = buf; ptr < buf + ifc.ifc_len; )
    {
       struct ifreq *ifr =(struct ifreq *) ptr;
       int len = sizeof(struct sockaddr);
-#ifdef	HAVE_SOCKADDR_SA_LEN
+#ifdef	HAVE_STRUCT_SOCKADDR_SA_LEN
       if (ifr->ifr_addr.sa_len > len)
          len = ifr->ifr_addr.sa_len;		/* length > 16 */
 #endif
@@ -72,44 +89,104 @@ NICList* findNICs()
 
       int flags;
       struct sockaddr_in *sinptr;
+      MyNIC *tmp=0;
       switch (ifr->ifr_addr.sa_family)
       {
       case AF_INET:
          sinptr = (struct sockaddr_in *) &ifr->ifr_addr;
          flags=0;
-         //printf("%s\t%s \n", ifr->ifr_name,inet_ntoa(sinptr->sin_addr));
 
          struct ifreq ifcopy;
          ifcopy=*ifr;
          result=ioctl(sockfd,SIOCGIFFLAGS,&ifcopy);
-         //cout<<"result from ioctl: "<<result<<endl;
          flags=ifcopy.ifr_flags;
-         if (((flags & IFF_UP) == IFF_UP)
-            && ((flags & IFF_BROADCAST) == IFF_BROADCAST)
-            && ((flags & IFF_LOOPBACK) == 0))
+
+         tmp=new MyNIC;
+         tmp->name=ifr->ifr_name;
+         if ((flags & IFF_UP) == IFF_UP)
+            tmp->state=i18n("Up");
+         else
+            tmp->state=i18n("Down");
+
+         if ((flags & IFF_BROADCAST) == IFF_BROADCAST)
+            tmp->type=i18n("Broadcast");
+         else if ((flags & IFF_POINTOPOINT) == IFF_POINTOPOINT)
+            tmp->type=i18n("Point to Point");
+#ifndef _AIX
+         else if ((flags & IFF_MULTICAST) == IFF_MULTICAST)
+            tmp->type=i18n("Multicast");
+#endif
+         else if ((flags & IFF_LOOPBACK) == IFF_LOOPBACK)
+            tmp->type=i18n("Loopback");
+         else
+            tmp->type=i18n("Unknown");
+
+         tmp->addr=inet_ntoa(sinptr->sin_addr);
+
+         ifcopy=*ifr;
+         result=ioctl(sockfd,SIOCGIFNETMASK,&ifcopy);
+         if (result==0)
          {
-            //yes, we are interested in this one :-)
-            ifcopy=*ifr;
-            result=ioctl(sockfd,SIOCGIFNETMASK,&ifcopy);
-            //cout<<"result from ioctl: "<<result<<endl;
-            MyNIC *tmp=new MyNIC;
-            tmp->name=ifr->ifr_name;
-            tmp->addr=*sinptr;
             sinptr = (struct sockaddr_in *) &ifcopy.ifr_addr;
-            //flags=0;
-            //printf("%s\t%s \n", ifcopy.ifr_name,inet_ntoa(sinptr->sin_addr));
-            tmp->netmask=*sinptr;
-            nl->append(tmp);
+            tmp->netmask=inet_ntoa(sinptr->sin_addr);
          }
-
-
+         else
+            tmp->netmask=i18n("Unknown");
+         nl->append(tmp);
          break;
 
       default:
-         //printf("%s\n", ifr->ifr_name);
          break;
       }
    }
+#else
+  struct ifaddrs *ifap, *ifa;
+  if (getifaddrs(&ifap) != 0) {
+    return nl;
+  }
+
+  MyNIC *tmp=0;
+  for (ifa = ifap; ifa; ifa = ifa->ifa_next) {
+    switch (ifa->ifa_addr->sa_family) {
+    case AF_INET6:
+    case AF_INET: {
+      tmp = new MyNIC;
+      tmp->name = ifa->ifa_name;
+
+      char buf[128];
+
+      bzero(buf, 128);
+      getnameinfo(ifa->ifa_addr, ifa->ifa_addr->sa_len, buf, 127, 0, 0, NI_NUMERICHOST);
+      tmp->addr = buf;
+
+      if (ifa->ifa_netmask != NULL) {
+#ifdef Q_OS_FREEBSD
+	struct sockaddr_in *sinptr = (struct sockaddr_in *)ifa->ifa_netmask;
+	tmp->netmask=inet_ntoa(sinptr->sin_addr);
+#else
+	bzero(buf, 128);
+	getnameinfo(ifa->ifa_netmask, ifa->ifa_netmask->sa_len, buf, 127, 0, 0, NI_NUMERICHOST);
+	tmp->netmask = buf;
+#endif
+      }
+
+      if (ifa->ifa_flags & IFF_UP)
+	tmp->state=i18n("Up");
+      else
+	tmp->state=i18n("Down");
+
+      tmp->type = flags_tos(ifa->ifa_flags);
+
+      nl->append(tmp);
+      break;
+    }
+    default:
+      break;
+    }
+  }
+
+  freeifaddrs(ifap);
+#endif
    return nl;
 }
 
@@ -121,8 +198,8 @@ void suggestSettingsForAddress(const QString& addrMask, LisaConfigInfo& lci)
    if (mask[mask.length()-1]==';')
       mask=mask.left(mask.length()-1);
    MyNIC tmpNic;
-   KInetSocketAddress::stringToAddr(AF_INET, mask.latin1(), &tmpNic.netmask.sin_addr);
-   KInetSocketAddress::stringToAddr(AF_INET, ip.latin1(), &tmpNic.addr.sin_addr);
+   KInetSocketAddress::stringToAddr(AF_INET, mask.latin1(), &tmpNic.netmask);
+   KInetSocketAddress::stringToAddr(AF_INET, ip.latin1(), &tmpNic.addr);
    suggestSettingsForNic(&tmpNic,lci);
 }
 
@@ -131,11 +208,14 @@ void suggestSettingsForNic(MyNIC* nic, LisaConfigInfo& lci)
    lci.clear();
    if (nic==0)
       return;
-   QString address=inet_ntoa(nic->addr.sin_addr);
-   QString netmask=inet_ntoa(nic->netmask.sin_addr);
+   QString address = nic->addr;
+   QString netmask = nic->netmask;
 
    QString addrMask(address+"/"+netmask+";");
-   unsigned int tmp=ntohl(nic->netmask.sin_addr.s_addr);
+   struct in_addr tmpaddr;
+   inet_aton(nic->netmask.latin1(), &tmpaddr);
+   unsigned int tmp= ntohl(tmpaddr.s_addr);
+
    //if the host part is less than 20 bits simply take it
    //this might be a problem on 64 bit machines
    if (tmp>0xfffff000)
@@ -185,3 +265,34 @@ void LisaConfigInfo::clear()
    unnamedHosts=false;
 }
 
+#if defined(HAVE_GETNAMEINFO) && defined(HAVE_GETIFADDRS)
+QString flags_tos (unsigned int flags)
+{
+  QString tmp;
+  if (flags & IFF_POINTOPOINT) {
+    tmp +=  i18n("Point to Point");
+  }
+
+  if (flags & IFF_BROADCAST) {
+    if (tmp.length()) {
+      tmp += QString::fromLatin1(", ");
+    }
+    tmp += i18n("Broadcast");
+  }
+  
+  if (flags & IFF_MULTICAST) {
+    if (tmp.length()) {
+      tmp += QString::fromLatin1(", ");
+    }
+    tmp += i18n("Multicast");
+  }
+  
+  if (flags & IFF_LOOPBACK) {
+    if (tmp.length()) {
+      tmp += QString::fromLatin1(", ");
+    }
+    tmp += i18n("Loopback");
+  }
+  return tmp;
+}
+#endif
