@@ -398,7 +398,7 @@ void SetupWizard::next()
          m_nicListBox->clear();
          for (MyNIC *nic=m_nics->first(); nic!=0; nic=m_nics->next())
          {
-            QString tmp=nic->name+": "+inet_ntoa(nic->addr.sin_addr)+"/"+inet_ntoa(nic->netmask.sin_addr)+";";
+            QString tmp=nic->name+": "+nic->addr+"/"+nic->netmask+";";
             m_nicListBox->insertItem(tmp);
          }
          m_nicListBox->setSelected(0,true);
@@ -444,7 +444,11 @@ void SetupWizard::next()
 void SetupWizard::showPage(QWidget* page)
 {
    if (page==m_noNicPage)
+   {
       m_manualAddress->setFocus();
+      setNextEnabled(m_noNicPage, false);
+      setHelpEnabled(m_noNicPage, false);
+   }
    else if (page==m_multiNicPage)
       m_nicListBox->setFocus();
    else if ( page == m_searchPage)
