@@ -42,7 +42,7 @@ Config::Config(const MyString& name/*,String path*/)
 /*   String s,empty="#############################################################################################################################################################";
    String home=getenv("HOME");
 
-   if (home!="") home+=String("/")+name;
+   if (!home.empty()) home+=String("/")+name;
    if (fexists(home)==0)
    {
       home=path+"/"+name;
