@@ -31,12 +31,15 @@ Led::Led ()
       static bool error_given = false;
       if (!error_given)
 	{
-	  kdWarning () <<
-	    "no Asus WLAN LED found, disabling LED updates\n";
+	  kdDebug () <<
+	    "No Asus WLAN LED found, disabling LED updates" << endl;
 	  error_given = true;
 	}
     }
   Off ();
+  // if Asusled not present, state never gets initialised, so we do it once here
+  // so that valgrind doesn't complain.
+  state = false;
 }
 
 Led::~Led ()
