@@ -22,7 +22,7 @@
 
 #include <qobject.h>
 #include <qstring.h>
-#include <qstringlist.h>
+#include <qtable.h>
 
 #ifndef WITHOUT_ARTS
 #include <arts/iomanager.h>
@@ -53,10 +53,10 @@ Q_OBJECT public:
   // if no device is attached, return empty QString
   virtual bool get_current_quality (int &sig, int &noi, int &qua);
   // quality info is only valid when true
-  virtual QStringList get_available_networks () = 0;
+  virtual QTable* get_available_networks () = 0;
   virtual bool get_has_txpower();
   virtual int get_txpower_disabled();
-
+  virtual void setActiveDevice( QString device ) = 0;
   // stats
   int sigLevel[MAX_HISTORY];
   int sigLevelMin, sigLevelMax;
