@@ -274,12 +274,12 @@ KWiFiManagerApp::slotChangeTrayIcon ()
 	led->Off ();
     }
 
-    if (showStrength) {
       QPixmap temp (m_iconSize+8, m_iconSize+8);
       QPainter bla (&temp);
       bla.fillRect (0, 0, m_iconSize+8, m_iconSize+8, backgroundBrush ());
       bla.drawPixmap ( QRect(1, 4, m_iconSize+2,m_iconSize+2), *ICON );
 
+      if (showStrength) {
   static QFont labelfont ( "Helvetica", 10 );
 
     labelfont.setStyleHint( QFont::SansSerif );
@@ -287,22 +287,15 @@ KWiFiManagerApp::slotChangeTrayIcon ()
     labelfont.setBold( true );
     sstrength2.setFont( labelfont );
     sstrength2.setFixedSize( sstrength2.sizeHint() );
+      }
     QPixmap labeltemp = QPixmap::grabWidget( &sstrength2 );
     labeltemp.setMask( labeltemp.createHeuristicMask() );
     bla.drawPixmap (0, 0, labeltemp );
   temp.setMask (temp.createHeuristicMask() );
   trayicon->setPixmap ( temp );
     this->setIcon( temp );
-    } else {
-      QPixmap temp (m_iconSize+8, m_iconSize+8);
-      QPainter bla (&temp);
-      bla.fillRect (0, 0, m_iconSize+8, m_iconSize+8, backgroundBrush ());
-      bla.drawPixmap ( QRect(1, 4, m_iconSize+2,m_iconSize+2), *ICON );
-
-      trayicon->setPixmap ( temp );
-      this->setIcon ( temp );
-    }
-  QToolTip::add( trayicon, "SSID: "+device->get_essid() );
+  
+    QToolTip::add( trayicon, "SSID: "+device->get_essid() );
 }
 
 void
@@ -400,6 +393,7 @@ KWiFiManagerApp::initView ()
   connect (device, SIGNAL (essidChanged (QString)), location, SLOT (repaint ()));
   connect (device, SIGNAL (statusChanged ()), location, SLOT (repaint ()));
   connect (device, SIGNAL (txPowerChanged ()), this, SLOT (slotTXPowerChanged ()));
+  connect (device, SIGNAL (txPowerChanged ()), this, SLOT (slotChangeTrayIcon ()));
   connect (device, SIGNAL (txPowerChanged ()), pictogram, SLOT (repaint ()));
   connect (device, SIGNAL (txPowerChanged ()), strength, SLOT (repaint ()));
   connect (scan,  SIGNAL (clicked()), this, SLOT (slotNetworkScan()));
@@ -564,7 +558,7 @@ void
 KWiFiManagerApp::slotStartConfigEditor ()
 {
   KProcess startConf;
-  startConf << "kdesu" << "kcmshell" << "kcmwifi";
+  startConf << "kdesu" << locate("exe", "kcmshell") << "kcmwifi";
   startConf.start (KProcess::DontCare);
 }
 
