@@ -22,11 +22,12 @@ class Interface_wireless;
 class Statistics:public QWidget
 {
 public:
-  Statistics (Interface_wireless * device);
+  Statistics (Interface_wireless * device, bool showStatsNoise);
 private:
   QPainter * statpainter;
   void paintEvent (QPaintEvent *);
   Interface_wireless *device;
+  bool showStatsNoise;
 };
 
 #endif
